@@ -6,8 +6,9 @@ import os
 
 
 from h_UI_selectContact import *
+from h_UI_helper import *
 
-class DetailsWindow(hildon.StackableWindow):
+class DetailsWindow(hildon.StackableWindow, h_UI_helper):
 
     def __init__(self, osmMapa, point, config):
         hildon.StackableWindow.__init__(self)
@@ -78,10 +79,7 @@ class DetailsWindow(hildon.StackableWindow):
             
             try:
                 if d['url']:
-                    bt_url = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                               hildon.BUTTON_ARRANGEMENT_VERTICAL,"Open web page")
-                    bt_url.connect("clicked",self.on_url, d['url'] )
-                    tlldbox.pack_start(bt_url, False)
+                    tlldbox.pack_start(self.bt("Open web page", self.on_url, d['url']), False)
             except:
                 pass
 
@@ -121,10 +119,7 @@ class DetailsWindow(hildon.StackableWindow):
                 l = gtk.Label("Phone: ")
                 hbox0.pack_start(l, False)
 
-                bt_phone = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"%s" % point[7]['tel'])
-                bt_phone.connect("clicked",self.on_call_clicked, point[7]['tel'] )
-                hbox0.pack_start(bt_phone, False)
+                hbox0.pack_start(self.bt("%s" % point[7]['tel'], self.on_call_clicked, point[7]['tel']), False)
 
                 tlldbox.pack_start( hbox0, True)
         except Exception, e:
@@ -160,25 +155,16 @@ class DetailsWindow(hildon.StackableWindow):
 
 
 
-        bt_mapa = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Mapa")
-        bt_mapa.connect("clicked", self.on_mapa, point[0], point[1])
-        self.bt_hbox.pack_start( bt_mapa, True)
+        self.bt_hbox.pack_start( self.bt("Mapa", self.on_mapa, point[0], point[1]), True)
 
 
 
 
         if self.CONFIG['POI']:
-            bt_poi = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"POI")
-            bt_poi.connect("clicked",self.on_add_as_poi,point[0],point[1])
-            self.bt_hbox.pack_start( bt_poi, True)
+            self.bt_hbox.pack_start( self.bt("POI",self.on_add_as_poi,point[0],point[1]), True)
 
         if self.CONFIG['Google - routesearch']:
-            bt_route = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Route")
-            bt_route.connect("clicked",self.on_route_to_it,point[0],point[1])
-            self.bt_hbox.pack_start( bt_route, True)
+            self.bt_hbox.pack_start( self.bt("Route",self.on_route_to_it,point[0],point[1]), True)
 
 
 
@@ -254,13 +240,8 @@ class DetailsWindow(hildon.StackableWindow):
                 l = gtk.Label("Phone: ")
                 hbox.pack_start(l, False)
 
-                bt_phone = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"%s" % ref_downloader.ref_result[2])
-
                 self.details_share = "%stel: %s; %s" % (self.details_share, ref_downloader.ref_result[2], ref_downloader.ref_result[1])
-
-                bt_phone.connect("clicked",self.on_call_clicked, ref_downloader.ref_result[2] )
-                hbox.pack_start( bt_phone, True)
+                hbox.pack_start( self.bt( "%s" % ref_downloader.ref_result[2], self.on_call_clicked, ref_downloader.ref_result[2] ), True)
 
                 tlldbox.pack_start( hbox, False)
 
@@ -270,10 +251,7 @@ class DetailsWindow(hildon.StackableWindow):
                 if self.osmMapa.send_to_contact_present():
                     self.bt_hbox.pack_start(self.osmMapa.send_to_contact_dialog(self.details_share), False)
 
-                bt_addContact = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                               hildon.BUTTON_ARRANGEMENT_VERTICAL,"Add Contact")
-                bt_addContact.connect("clicked",self.on_bt_addContact,ref_downloader.ref_result, point)
-                self.bt_hbox.pack_start( bt_addContact, True)
+                self.bt_hbox.pack_start( self.bt("Add Contact",self.on_bt_addContact,ref_downloader.ref_result, point), True)
                 bt_addContact.show_all()
 
 
@@ -328,13 +306,4 @@ class DetailsWindow(hildon.StackableWindow):
         self.destroy()
 
 
-    def get_label(self, str):
-        hbox = gtk.HBox( spacing = 5 )
-        l0 = gtk.Label()
-        l0.set_line_wrap( True )
-        l0.set_markup( str.replace("&","&amp;") )
-        hbox.pack_start( l0, False)
-
-        l1 = gtk.Label()
-        hbox.pack_start( l1, True)
-        return hbox
\ No newline at end of file
+    
\ No newline at end of file
