@@ -2,10 +2,12 @@ import hildon
 import gtk
 import gobject
 import md5
+import os
 
 from h_UI_selectContact import *
+from h_UI_helper import *
 
-class SearchDialog( hildon.StackableWindow ):
+class SearchDialog( hildon.StackableWindow, h_UI_helper ):
     def __init__(self, osmMapa, config ):
         hildon.StackableWindow.__init__(self)
         self.osmMapa = osmMapa
@@ -58,17 +60,14 @@ class SearchDialog( hildon.StackableWindow ):
             for s in self.CONFIG['recent_search']:
                 hbox = gtk.HBox()
                 try:
-                    f_name = "%s_%s.jpg" % (self.osmMapa.get_home(), md5.new(s[0]).hexdigest())
+                    f_name = "%s/.yosmapa_0.18.conf_%s.jpg" % (self.osmMapa.get_home(), md5.new(s[0]).hexdigest())
                     if os.path.isfile(f_name):
                         img = gtk.Image()
                         img.set_from_file(f_name)
                         hbox.pack_start(img,False)
-                except:
-                    pass
-                b = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,s[0])
-                b.connect("clicked", self.on_recent_click)
-                hbox.pack_start(b, True)
+                except Exception, e:
+                    print "find ico ERROR",e
+                hbox.pack_start(self.bt(s[0],self.on_recent_click), True)
                 mvbox.pack_start(hbox, False)
 
 
@@ -115,10 +114,7 @@ class SearchDialog( hildon.StackableWindow ):
         bt_c.connect("clicked", self.on_clean, e_search)
 
 
-        bt_search = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Find")
-        bt_search.connect("clicked", self.on_search, e_search)
-        hbox.pack_start(bt_search,False)
+        hbox.pack_start(self.bt("Find",self.on_search, e_search),False)
 
 
         self.vbox.pack_start(hbox,False)
@@ -147,10 +143,7 @@ class SearchDialog( hildon.StackableWindow ):
         l = gtk.Label( " " )
         hbox.pack_start(l,True)
 
-        bt = hildon.Button(gtk.HILDON_SIZE_AUTO_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT,
-                           hildon.BUTTON_ARRANGEMENT_VERTICAL,"Action")
-        bt.connect("clicked", self.on_result_release, i)
-        hbox.pack_start(bt, False)
+        hbox.pack_start(self.bt("Action", self.on_result_release, i), False)
 
         return hbox
 
