@@ -7,6 +7,13 @@ class google_link:
         self.osmMapa = osmMapa
         self.CONFIG = CONFIG
 
+        self.ico = "google_maps.png"
+        self.ui_menu_main = 1
+        self.ui_menu_left = 0
+        self.ui_stackable = 0
+        self.ui_search = 0
+
+
         print "__init__ google_link"
 
     def get_menu_widgets(self, dialog):
