@@ -156,28 +156,28 @@ class googleRoutesearchDownloader(Thread):
             if lang == "en":
 
                 if str.find("Continue straight") == 0:
-                    ico_name = "./plugins/ico_turn_32_32.png"
+                    ico_name = "./plugins/ico_t2_32_32.png"
                     ico = gdk.pixbuf_new_from_file(ico_name)
                 elif str.find("Turn left") == 0 or str.find("Take the 1st left") == 0 or str.find("Take the 2nd left") == 0 or str.find("Take the 3rd left") == 0:
-                    ico_name = "./plugins/ico_turn_left_32_32.png"
+                    ico_name = "./plugins/ico_t2_left_32_32.png"
                     ico = gdk.pixbuf_new_from_file(ico_name)
                 elif str.find("Turn right") == 0 or str.find("Take the 1st right") == 0 or str.find("Take the 2nd right") == 0 or str.find("Take the 3rd right") == 0:
-                    ico_name = "./plugins/ico_turn_right_32_32.png"
+                    ico_name = "./plugins/ico_t2_right_32_32.png"
                     ico = gdk.pixbuf_new_from_file(ico_name)
                 elif str.find("Slight right") == 0:
-                    ico_name = "./plugins/ico_turn_sright_32_32.png"
+                    ico_name = "./plugins/ico_t2_sright_32_32.png"
                     ico = gdk.pixbuf_new_from_file(ico_name)
                 elif str.find("Slight left") == 0:
-                    ico_name = "./plugins/ico_turn_sleft_32_32.png"
+                    ico_name = "./plugins/ico_t2_sleft_32_32.png"
                     ico = gdk.pixbuf_new_from_file( ico_name)
                 elif str.find("Keep left") == 0:
-                    ico_name = "./plugins/ico_turn_keep_left_32_32.png"
+                    ico_name = "./plugins/ico_t2_keep_left_32_32.png"
                     ico = gdk.pixbuf_new_from_file( ico_name)
                 elif str.find("Keep right") == 0:
-                    ico_name = "./plugins/ico_turn_keep_right_32_32.png"
+                    ico_name = "./plugins/ico_t2_keep_right_32_32.png"
                     ico = gdk.pixbuf_new_from_file( ico_name)
                 elif str.find("Make a U-turn") == 0 or str.find("Sharp left") == 0 or str.find("Sharp right") == 0:
-                    ico_name = "./plugins/ico_turn_u_32_32.png"
+                    ico_name = "./plugins/ico_t2_u_32_32.png"
                     ico = gdk.pixbuf_new_from_file( ico_name)
                 self.geonames.markers.append([
                                      float(sll[0]),float(sll[1]),
@@ -475,6 +475,8 @@ class google_routesearch(h_UI_helper, math_helper):
         if not self.drive_mode:
             return 0
         
+        key_deb = 0
+        
         #self.osmMapa.marker_draw_redraw_made = 0
         
         print "drive mode", self.drive_mode
@@ -485,7 +487,7 @@ class google_routesearch(h_UI_helper, math_helper):
                 markers_count = len( self.markers )-1
                 for nr, p in enumerate(self.markers):
                     if p[3] <> None:
-                        at_point = 0#self.get_point(p[0], p[1])
+                        at_point = self.get_point(p[0], p[1])
                         at_point_back = at_point
                         while at_point>0:
                             p0 =  self.points[at_point]
@@ -496,26 +498,72 @@ class google_routesearch(h_UI_helper, math_helper):
                             if at_point_back < 0:
                                 at_point = 0
                                 break
-                            if dis < 0.01:
+                            if dis < 0.02:
                                 at_point_back-=1
                             else:
-                                if p1[0] == p0[0] or p1[1] == p0[1]:
-                                    at_point_back-=1
-                                else:
-                                    break
+                                break
                         
                         ico_turn = p[3]
+                        ico_name = p[4]
                         if at_point and at_point >0 and markers_count > nr:
-                            angle = self.cal_angle(
-                                    self.points[at_point_back][0],
-                                    self.points[at_point_back][1],
-                                    self.points[at_point][0],
-                                    self.points[at_point][1]                                    
-                                    )[0]
-                            angle = 7-round(int(math.degrees(angle))/90)
-                            ico_turn = ico_turn.rotate_simple( (angle*90) )
-                        #self.osmMapa.osm.image_add( p[0], p[1], ico_turn )
-                        self.markers_icons.append( self.osmMapa.osm.image_add( p[0], p[1], ico_turn ) )
+                            p0 =  self.points[at_point]
+                            p1 =  self.points[at_point_back]
+                            angle0 = self.cal_angle( p1[1], p1[0], p0[1], p0[0] )[0]
+                            aToS = (360-int(math.degrees(angle0)))%360
+                            
+                            
+                            if aToS>=-22.5 and aToS<22.5 : 
+                                aStr = "N"
+                                rotate_by = 0
+                            elif aToS>=22.5 and aToS<67.5: 
+                                aStr = "NE"
+                                rotate_by = 0
+                            elif aToS>=67.5 and aToS<112.5: 
+                                aStr = "E"
+                                rotate_by = 90
+                            elif aToS>=112.5 and aToS<157.5: 
+                                aStr = "SE"
+                                rotate_by = 90
+                            elif aToS>=157.5 and aToS<202.5: 
+                                aStr = "S"
+                                rotate_by = 180
+                            elif aToS>=205.5 and aToS<247.5: 
+                                aStr = "SW"
+                                rotate_by = 180
+                            elif aToS>=247.5 and aToS<292.5:
+                                aStr = "W"
+                                rotate_by = 270
+                            elif aToS>=292.5 and aToS<337.5: 
+                                aStr = "NW"
+                                rotate_by = 270
+                            elif aToS>=337.5 and aToS<382.5: 
+                                aStr = "N"
+                                rotate_by = 0
+                            
+                            if len(aStr) == 2:
+                                ico_name = ico_name.replace("_32_32.", "_45_32_32.")
+                                
+                            ico_turn = gdk.pixbuf_new_from_file( ico_name )
+                            ico_turn = ico_turn.rotate_simple( 360-rotate_by )
+                                
+                            
+                            if key_deb == 1:
+                                
+                                cr = gdkdrawable.cairo_create()            
+                                x,y = self.osmMapa.osm.geographic_to_screen(p0[0],p0[1])
+                                if x>0and y>0:
+                                   self.osmMapa.draw_cloud( cr, x,y+10, "(%i)p0[%i]\n%s\n%i"% (at_point,at_point,aStr, aToS) )
+                
+                                
+                                x,y = self.osmMapa.osm.geographic_to_screen(p1[0],p1[1])
+                                if x>0and y>0:
+                                    self.osmMapa.draw_cloud( cr, x,y, ("(%i)p1[%i]"%(at_point,at_point_back)) )
+                                
+                            #ico_turn = ico_turn.rotate_simple( angle )
+                        if key_deb == 0:
+                            self.markers_icons.append( self.osmMapa.osm.image_add( p[0], p[1], ico_turn ) )
+                        else:
+                            self.osmMapa.osm.image_add( p[0], p[1], ico_turn )
             
             if self.osmMapa.get_gpslock() == 0:
 
@@ -530,7 +578,8 @@ class google_routesearch(h_UI_helper, math_helper):
                     #print "lt:",t_lt,t_ln,"\t c:",lt,ln,"\tb:",b_lt,b_ln
                     if t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
                         x,y = self.osmMapa.osm.geographic_to_screen(lt,ln)
-                        self.osmMapa.draw_cloud( cr, x,y, p[2])
+                        if key_deb == 0:
+                            self.osmMapa.draw_cloud( cr, x,y, p[2])
 
         else:
             for i in self.markers_icons:
