@@ -8,7 +8,7 @@ from xml.dom.minidom import Node
 import math
 import osmgpsmap
 import gobject
-
+from threading import Thread
 from h_UI_helper import *
 
 
@@ -31,21 +31,24 @@ class LoadTrackDialog( hildon.Program):
         return tr
 
 
-class GpxLoad:
+class GpxLoad(Thread):
 
     lines = []
     points = []
 
-    def __init__(self, fileToLoad):
+    def __init__(self, pa, fileToLoad):
+        Thread.__init__(self)
         self.lines = []
         self.points = []
-
-
-
         self.file = fileToLoad
+        self.pa = pa
+        
+    def run(self):
+        t = time.time()
+        self.doc = xml.dom.minidom.parseString( open( self.file,"r").read() )
+        print "gpi_tracks load parse in ", (time.time()-t)
 
-        self.doc = xml.dom.minidom.parse(self.file)
-
+        t = time.time()
         try:
             for trkseg in self.doc.getElementsByTagName("trkseg"):
                 line = []
@@ -76,8 +79,11 @@ class GpxLoad:
                 self.points.append( point )
         except:
             print "points error"
-    def getResult(self):
-        return self.lines,self.points
+        
+        print "gpi_tracks load parse2 in ", (time.time()-t)
+    
+        self.pa.on_load_done(self.lines,self.points)
+        
 
 class SaveTrackDialog( hildon.Program):
     def __init__(self, zoom=0, lat=0, lon=0):
@@ -169,8 +175,7 @@ class gpx_tracks( h_UI_helper):
     def clear_my_layer(self):
         for t in self.osm_tracks:
             self.osmMapa.osm.track_remove(t)
-        self.osm_tracks = []
-        
+        self.osm_tracks = []        
         self.osmMapa.marker_layer_clean( self.get_name() )
 
     def killIt(self):
@@ -181,8 +186,8 @@ class gpx_tracks( h_UI_helper):
         if self.CONFIG['gpxtrack'] and self.CONFIG['gpxfile']:
             print "parse track start"
             try:
-                self.tracks_gpx, self.points_gpx = GpxLoad( self.CONFIG['gpxfile'] ).getResult()
-                self.track_point_rebuild()
+                g = GpxLoad( self, self.CONFIG['gpxfile'] )
+                g.start()
             except:
                 self.clear_my_layer()
                 pass
@@ -205,7 +210,7 @@ class gpx_tracks( h_UI_helper):
 
         dialog.destroy()
 
-    def on_load(self,widget, dialog, bt_offline):
+    def on_load(self,widget, dialog):
         print "load track start"
         track = LoadTrackDialog()
         file = track.startIt()
@@ -214,21 +219,28 @@ class gpx_tracks( h_UI_helper):
             self.CONFIG['gpxtrack'] = 1
             self.CONFIG['gpxfile'] = file
             print "parse track start"
-            self.tracks_gpx, self.points_gpx = GpxLoad( file ).getResult()
+            g = GpxLoad( self, file )
+            g.start()
             print "parse track start DONE"
-            if bt_offline.get_active():
-                print "zoom_select start"
-                zoom_select = MyZoomSelect(self)
-                zoom_select.run()
-                print "zoom_select done"
-
-            self.track_point_rebuild( bt_offline.get_active(),self.zoom_min, self.zoom_max )
+            
 
         track = None
         dialog.destroy()
         print "load track start DONE"
 
+    def on_load_done(self, tracks, points):
+        self.tracks_gpx = tracks
+        self.points_gpx = points
+        
+        if self.bt_offline.get_active():
+            print "zoom_select start"
+            zoom_select = MyZoomSelect(self)
+            zoom_select.run()
+            print "zoom_select done"
 
+        t = time.time()
+        self.track_point_rebuild( self.zoom_min, self.zoom_max )
+        print "gpi_tracks rebuild in ", (time.time()-t)
 
 
     def on_save(self,widget, dialog):
@@ -266,9 +278,7 @@ class gpx_tracks( h_UI_helper):
 
 
 
-    def track_point_rebuild(self, downloadIt = False, zoom_min = 10, zoom_max = 16):
-        print "track_point_rebuild downloadIt",downloadIt
-
+    def track_point_rebuild(self, zoom_min = 10, zoom_max = 16):
         self.clear_my_layer()
         # track & download
         ll0 = 0,0
@@ -291,7 +301,7 @@ class gpx_tracks( h_UI_helper):
 
                 t.add_point( point )
 
-                if downloadIt:
+                if self.bt_offline.get_active():
                     if ll0 == [0,0]:
                         ll0 = p
                     else:
@@ -335,11 +345,11 @@ class gpx_tracks( h_UI_helper):
 
 
         vbox = gtk.VBox()
-        bt_offline = hildon.CheckButton(gtk.HILDON_SIZE_AUTO| gtk.HILDON_SIZE_FINGER_HEIGHT)
-        bt_offline.set_label("Work offline")
-        vbox.pack_start(bt_offline, pack)
+        self.bt_offline = hildon.CheckButton(gtk.HILDON_SIZE_AUTO| gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.bt_offline.set_label("Work offline")
+        vbox.pack_start(self.bt_offline, pack)
 
-        vbox.pack_start(self.bt("Load track", self.on_load, dialog,bt_offline),pack)
+        vbox.pack_start(self.bt("Load track", self.on_load, dialog),pack)
 
         hbox.pack_start( vbox, pack)
 
