@@ -10,7 +10,9 @@ import osmgpsmap
 import gobject
 import md5
 
-class results_view:
+from h_UI_helper import *
+
+class results_view(h_UI_helper):
 
     def __init__(self,osmMapa,CONFIG):
         self.osmMapa = osmMapa
@@ -21,7 +23,9 @@ class results_view:
         self.ui_menu_left = 1
         self.ui_stackable = 1
         self.ui_search = 0
-
+        self.limit_start = 0
+        self.limit_count = 20
+        
 
         self.scroll_at = [0,0]
 
@@ -32,17 +36,7 @@ class results_view:
 
     def makeInit(self):
         return None
-
-    def get_label(self, str):
-        hbox = gtk.HBox( spacing = 5 )
-        l0 = gtk.Label()
-        l0.set_line_wrap( True )
-        l0.set_markup( str )
-        hbox.pack_start( l0, False)
-
-        l1 = gtk.Label()
-        hbox.pack_start( l1, True)
-        return hbox
+ 
 
     def get_menu_widgets(self, dialog):
         vbox = gtk.VBox()
@@ -67,22 +61,32 @@ class results_view:
                 
         
 
-        mvbox = gtk.VBox()
+        self.mvbox = gtk.VBox()
         self.panel = hildon.PannableArea()
-        self.panel.add_with_viewport(mvbox)
+        self.panel.add_with_viewport(self.mvbox )
         vbox.pack_start( self.panel, True)
+        self.add_items_to_list( make_from,dialog )
 
-        store = gtk.ListStore( str, str, str,str )
-        for m in make_from:
+        self.mvbox .show_all()
+
+        return vbox
+
+    def add_items_to_list(self, make_from,dialog):
+        more = 0
+        added = 0
+        for nr,m in enumerate(make_from):
             #print m
-            if m[3]:
+            if m[3] and added < self.limit_count and nr >= self.limit_start:
+                added+=1
+                
                 osm = osmgpsmap.GpsMap()
                 osm.set_center_and_zoom( m[0], m[1], 16 )
                 osm.set_size_request(140, 140)
                 osm.image_add( m[0], m[1], m[4] )
                 osm.connect('button_release_event', self.on_map_clicked, m[0], m[1],dialog)
                 osm.connect('button_press_event', self.on_map_clicked, m[0], m[1],dialog)
-
+                
+                
                 dbox = gtk.VBox()
                 l = self.get_label("<b>%s</b>"%m[3])
                 dbox.pack_start( l, False)
@@ -100,15 +104,20 @@ class results_view:
                 ebox.connect("button-press-event", self.on_ebox_click)
                 ebox.connect("button-release-event", self.on_ebox_release_click, m,dialog)
 
-                mvbox.pack_start( gtk.HSeparator(), False)
-                mvbox.pack_start( ebox, False)
-
-
-
-        mvbox.show_all()
-
-        return vbox
+                self.mvbox .pack_start( gtk.HSeparator(), False)
+                self.mvbox .pack_start( ebox, False)
+            else:
+                more = 1
+        
+        if more:
+            self.mvbox.pack_start( self.bt("More", self.on_bt_more, make_from,dialog), True)
     
+    def on_bt_more(self,w, make_from,dialog):
+        self.panel.hide()
+        w.destroy()
+        self.limit_start+=self.limit_count
+        self.add_items_to_list( make_from,dialog)
+        self.panel.show_all()
     
     def on_ebox_click(self,w,a):
         self.scroll_at = [ self.panel.get_vadjustment().get_value(), self.panel.get_hadjustment().get_value() ]
